@@ -3,7 +3,7 @@ Cancel a downtime returns "OK" response
 """
 
 from os import environ
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.downtimes_api import DowntimesApi
 
 # there is a valid "downtime" in the system
