@@ -2,7 +2,7 @@
 Get all hosts for your organization returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.hosts_api import HostsApi
 
 configuration = Configuration()
