@@ -2,7 +2,7 @@
 Mute a host returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.hosts_api import HostsApi
 from datadog_api_client.v1.model.host_mute_settings import HostMuteSettings
 
