@@ -4,7 +4,7 @@ Query timeseries points returns "OK" response
 
 from datetime import datetime
 from dateutil.relativedelta import relativedelta
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.metrics_api import MetricsApi
 
 configuration = Configuration()
