@@ -3,7 +3,7 @@ Check if a monitor can be deleted returns "OK" response
 """
 
 from os import environ
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.monitors_api import MonitorsApi
 
 # there is a valid "monitor" in the system
