@@ -2,7 +2,7 @@
 Get organization information returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.organizations_api import OrganizationsApi
 
 configuration = Configuration()
