@@ -2,7 +2,7 @@
 Create a new service object returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.pager_duty_integration_api import PagerDutyIntegrationApi
 from datadog_api_client.v1.model.pager_duty_service import PagerDutyService
 
