@@ -2,7 +2,7 @@
 Delete a single service object returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.pager_duty_integration_api import PagerDutyIntegrationApi
 
 configuration = Configuration()
