@@ -1,8 +1,8 @@
 """
-Get hourly usage for Synthetics Checks returns "OK" response
+Get hourly usage for synthetics checks returns "OK" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.usage_metering_api import UsageMeteringApi
 from datetime import datetime
 from dateutil.tz import tzutc
