@@ -4,14 +4,14 @@ Get all custom metrics by hourly average returns "OK" response
 
 from datetime import datetime
 from dateutil.relativedelta import relativedelta
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.usage_metering_api import UsageMeteringApi
 
 configuration = Configuration()
 with ApiClient(configuration) as api_client:
     api_instance = UsageMeteringApi(api_client)
     response = api_instance.get_usage_top_avg_metrics(
-        day=(datetime.now() + relativedelta(days=-3)).isoformat(timespec="seconds"),
+        day=(datetime.now() + relativedelta(days=-3)),
     )
 
     print(response)
