@@ -2,7 +2,7 @@
 Create a user returns "User created" response
 """
 
-from datadog_api_client.v1 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v1.api.users_api import UsersApi
 from datadog_api_client.v1.model.access_role import AccessRole
 from datadog_api_client.v1.model.user import User
