@@ -2,7 +2,7 @@
 Create a tag configuration returns "Created" response
 """
 
-from datadog_api_client.v2 import ApiClient, Configuration
+from datadog_api_client import ApiClient, Configuration
 from datadog_api_client.v2.api.metrics_api import MetricsApi
 from datadog_api_client.v2.model.metric_tag_configuration_create_attributes import (
     MetricTagConfigurationCreateAttributes,
@@ -27,7 +27,6 @@ body = MetricTagConfigurationCreateRequest(
 )
 
 configuration = Configuration()
-configuration.unstable_operations["create_tag_configuration"] = True
 with ApiClient(configuration) as api_client:
     api_instance = MetricsApi(api_client)
     response = api_instance.create_tag_configuration(
