@@ -9,22 +9,14 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.widget_time import WidgetTime
-    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
-    from datadog_api_client.v1.model.alert_graph_widget_definition_type import AlertGraphWidgetDefinitionType
-    from datadog_api_client.v1.model.widget_viz_type import WidgetVizType
-
-    globals()["WidgetTime"] = WidgetTime
-    globals()["WidgetTextAlign"] = WidgetTextAlign
-    globals()["AlertGraphWidgetDefinitionType"] = AlertGraphWidgetDefinitionType
-    globals()["WidgetVizType"] = WidgetVizType
-
-
 class AlertGraphWidgetDefinition(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.widget_time import WidgetTime
+        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
+        from datadog_api_client.v1.model.alert_graph_widget_definition_type import AlertGraphWidgetDefinitionType
+        from datadog_api_client.v1.model.widget_viz_type import WidgetVizType
+
         return {
             "alert_id": (str,),
             "time": (WidgetTime,),
