@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.api_key import ApiKey
-
-    globals()["ApiKey"] = ApiKey
-
-
 class ApiKeyResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.api_key import ApiKey
+
         return {
             "api_key": (ApiKey,),
         }
