@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class AWSLogsAsyncError(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "code": (str,),
             "message": (str,),
@@ -25,8 +22,6 @@ class AWSLogsAsyncError(ModelNormal):
         "message": "message",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Description of errors.
