@@ -10,16 +10,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.azure_account import AzureAccount
-
-    globals()["AzureAccount"] = AzureAccount
-
-
 class AzureAccountListResponse(ModelSimple):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.azure_account import AzureAccount
+
         return {
             "value": ([AzureAccount],),
         }
@@ -30,7 +25,6 @@ class AzureAccountListResponse(ModelSimple):
 
         Note that value can be passed either in args or in kwargs, but not in both.
 
-        :param value: Accounts configured for your organization.
         :type value: [AzureAccount]
         """
         super().__init__(kwargs)
