@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.check_can_delete_slo_response_data import CheckCanDeleteSLOResponseData
-
-    globals()["CheckCanDeleteSLOResponseData"] = CheckCanDeleteSLOResponseData
-
-
 class CheckCanDeleteSLOResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.check_can_delete_slo_response_data import CheckCanDeleteSLOResponseData
+
         return {
             "data": (CheckCanDeleteSLOResponseData,),
             "errors": ({str: (str,)},),
