@@ -10,16 +10,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.dashboard_bulk_action_data import DashboardBulkActionData
-
-    globals()["DashboardBulkActionData"] = DashboardBulkActionData
-
-
 class DashboardBulkActionDataList(ModelSimple):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.dashboard_bulk_action_data import DashboardBulkActionData
+
         return {
             "value": ([DashboardBulkActionData],),
         }
@@ -30,7 +25,6 @@ class DashboardBulkActionDataList(ModelSimple):
 
         Note that value can be passed either in args or in kwargs, but not in both.
 
-        :param value: List of dashboard bulk action request data objects.
         :type value: [DashboardBulkActionData]
         """
         super().__init__(kwargs)
