@@ -9,14 +9,6 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.event_alert_type import EventAlertType
-    from datadog_api_client.v1.model.event_priority import EventPriority
-
-    globals()["EventAlertType"] = EventAlertType
-    globals()["EventPriority"] = EventPriority
-
-
 class EventCreateRequest(ModelNormal):
     validations = {
         "aggregation_key": {
@@ -29,7 +21,9 @@ class EventCreateRequest(ModelNormal):
 
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.event_alert_type import EventAlertType
+        from datadog_api_client.v1.model.event_priority import EventPriority
+
         return {
             "aggregation_key": (str,),
             "alert_type": (EventAlertType,),
@@ -67,8 +61,8 @@ class EventCreateRequest(ModelNormal):
         :type aggregation_key: str, optional
 
         :param alert_type: If an alert event is enabled, set its type.
-            For example, `error`, `warning`, `info`, `success`, `user_update`,
-            `recommendation`, and `snapshot`.
+            For example, ``error`` , ``warning`` , ``info`` , ``success`` , ``user_update`` ,
+            ``recommendation`` , and ``snapshot``.
         :type alert_type: EventAlertType, optional
 
         :param date_happened: POSIX timestamp of the event. Must be sent as an integer (that is no quotes).
@@ -82,22 +76,22 @@ class EventCreateRequest(ModelNormal):
             Any tags associated with the host are also applied to this event.
         :type host: str, optional
 
-        :param priority: The priority of the event. For example, `normal` or `low`.
+        :param priority: The priority of the event. For example, ``normal`` or ``low``.
         :type priority: EventPriority, none_type, optional
 
         :param related_event_id: ID of the parent event. Must be sent as an integer (that is no quotes).
         :type related_event_id: int, optional
 
         :param source_type_name: The type of event being posted. Option examples include nagios, hudson, jenkins, my_apps, chef, puppet, git, bitbucket, etc.
-            A complete list of source attribute values [available here](https://docs.datadoghq.com/integrations/faq/list-of-api-source-attribute-value).
+            A complete list of source attribute values `available here <https://docs.datadoghq.com/integrations/faq/list-of-api-source-attribute-value>`_.
         :type source_type_name: str, optional
 
         :param tags: A list of tags to apply to the event.
         :type tags: [str], optional
 
         :param text: The body of the event. Limited to 4000 characters. The text supports markdown.
-            To use markdown in the event text, start the text block with `%%% \n` and end the text block with `\n %%%`.
-            Use `msg_text` with the Datadog Ruby library.
+            To use markdown in the event text, start the text block with ``%%% \\n`` and end the text block with ``\\n %%%``.
+            Use ``msg_text`` with the Datadog Ruby library.
         :type text: str
 
         :param title: The event title.
