@@ -18,6 +18,7 @@ class FormulaAndFunctionApmResourceStatName(ModelSimple):
             "ERROR_RATE": "error_rate",
             "HITS": "hits",
             "LATENCY_AVG": "latency_avg",
+            "LATENCY_DISTRIBUTION": "latency_distribution",
             "LATENCY_MAX": "latency_max",
             "LATENCY_P50": "latency_p50",
             "LATENCY_P75": "latency_p75",
@@ -39,7 +40,7 @@ class FormulaAndFunctionApmResourceStatName(ModelSimple):
 
         Note that value can be passed either in args or in kwargs, but not in both.
 
-        :param value: Must be one of ["errors", "error_rate", "hits", "latency_avg", "latency_max", "latency_p50", "latency_p75", "latency_p90", "latency_p95", "latency_p99"].
+        :param value: Must be one of ["errors", "error_rate", "hits", "latency_avg", "latency_distribution", "latency_max", "latency_p50", "latency_p75", "latency_p90", "latency_p95", "latency_p99"].
         :type value: str
         """
         super().__init__(kwargs)
