@@ -9,18 +9,12 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
-    from datadog_api_client.v1.model.free_text_widget_definition_type import FreeTextWidgetDefinitionType
-
-    globals()["WidgetTextAlign"] = WidgetTextAlign
-    globals()["FreeTextWidgetDefinitionType"] = FreeTextWidgetDefinitionType
-
-
 class FreeTextWidgetDefinition(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
+        from datadog_api_client.v1.model.free_text_widget_definition_type import FreeTextWidgetDefinitionType
+
         return {
             "color": (str,),
             "font_size": (str,),
