@@ -9,24 +9,6 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
-    from datadog_api_client.v1.model.geomap_widget_request import GeomapWidgetRequest
-    from datadog_api_client.v1.model.geomap_widget_definition_style import GeomapWidgetDefinitionStyle
-    from datadog_api_client.v1.model.widget_time import WidgetTime
-    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
-    from datadog_api_client.v1.model.geomap_widget_definition_type import GeomapWidgetDefinitionType
-    from datadog_api_client.v1.model.geomap_widget_definition_view import GeomapWidgetDefinitionView
-
-    globals()["WidgetCustomLink"] = WidgetCustomLink
-    globals()["GeomapWidgetRequest"] = GeomapWidgetRequest
-    globals()["GeomapWidgetDefinitionStyle"] = GeomapWidgetDefinitionStyle
-    globals()["WidgetTime"] = WidgetTime
-    globals()["WidgetTextAlign"] = WidgetTextAlign
-    globals()["GeomapWidgetDefinitionType"] = GeomapWidgetDefinitionType
-    globals()["GeomapWidgetDefinitionView"] = GeomapWidgetDefinitionView
-
-
 class GeomapWidgetDefinition(ModelNormal):
     validations = {
         "requests": {
@@ -37,7 +19,14 @@ class GeomapWidgetDefinition(ModelNormal):
 
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
+        from datadog_api_client.v1.model.geomap_widget_request import GeomapWidgetRequest
+        from datadog_api_client.v1.model.geomap_widget_definition_style import GeomapWidgetDefinitionStyle
+        from datadog_api_client.v1.model.widget_time import WidgetTime
+        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
+        from datadog_api_client.v1.model.geomap_widget_definition_type import GeomapWidgetDefinitionType
+        from datadog_api_client.v1.model.geomap_widget_definition_view import GeomapWidgetDefinitionView
+
         return {
             "custom_links": ([WidgetCustomLink],),
             "requests": ([GeomapWidgetRequest],),
@@ -69,10 +58,10 @@ class GeomapWidgetDefinition(ModelNormal):
         :param custom_links: A list of custom links.
         :type custom_links: [WidgetCustomLink], optional
 
-        :param requests: Array of one request object to display in the widget. The request must contain a `group-by` tag whose value is a country ISO code.
+        :param requests: Array of one request object to display in the widget. The request must contain a ``group-by`` tag whose value is a country ISO code.
 
-            See the [Request JSON schema documentation](https://docs.datadoghq.com/dashboards/graphing_json/request_json)
-            for information about building the `REQUEST_SCHEMA`.
+            See the `Request JSON schema documentation <https://docs.datadoghq.com/dashboards/graphing_json/request_json>`_
+            for information about building the ``REQUEST_SCHEMA``.
         :type requests: [GeomapWidgetRequest]
 
         :param style: The style to apply to the widget.
