@@ -10,6 +10,10 @@ from datadog_api_client.model_utils import (
 
 
 class HTTPLogItem(ModelNormal):
+    @cached_property
+    def additional_properties_type(_):
+        return (str,)
+
     @cached_property
     def openapi_types(_):
         return {
@@ -34,7 +38,7 @@ class HTTPLogItem(ModelNormal):
 
         :param ddsource: The integration name associated with your log: the technology from which the log originated.
             When it matches an integration name, Datadog automatically installs the corresponding parsers and facets.
-            See [reserved attributes](https://docs.datadoghq.com/logs/log_collection/#reserved-attributes).
+            See `reserved attributes <https://docs.datadoghq.com/logs/log_collection/#reserved-attributes>`_.
         :type ddsource: str, optional
 
         :param ddtags: Tags associated with your logs.
@@ -43,14 +47,14 @@ class HTTPLogItem(ModelNormal):
         :param hostname: The name of the originating host of the log.
         :type hostname: str, optional
 
-        :param message: The message [reserved attribute](https://docs.datadoghq.com/logs/log_collection/#reserved-attributes)
+        :param message: The message `reserved attribute <https://docs.datadoghq.com/logs/log_collection/#reserved-attributes>`_
             of your log. By default, Datadog ingests the value of the message attribute as the body of the log entry.
             That value is then highlighted and displayed in the Logstream, where it is indexed for full text search.
         :type message: str
 
         :param service: The name of the application or service generating the log events.
             It is used to switch from Logs to APM, so make sure you define the same value when you use both products.
-            See [reserved attributes](https://docs.datadoghq.com/logs/log_collection/#reserved-attributes).
+            See `reserved attributes <https://docs.datadoghq.com/logs/log_collection/#reserved-attributes>`_.
         :type service: str, optional
         """
         super().__init__(kwargs)
