@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.logs_by_retention_org_usage import LogsByRetentionOrgUsage
-
-    globals()["LogsByRetentionOrgUsage"] = LogsByRetentionOrgUsage
-
-
 class LogsByRetentionOrgs(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.logs_by_retention_org_usage import LogsByRetentionOrgUsage
+
         return {
             "usage": ([LogsByRetentionOrgUsage],),
         }
