@@ -9,14 +9,6 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.logs_grok_parser_rules import LogsGrokParserRules
-    from datadog_api_client.v1.model.logs_grok_parser_type import LogsGrokParserType
-
-    globals()["LogsGrokParserRules"] = LogsGrokParserRules
-    globals()["LogsGrokParserType"] = LogsGrokParserType
-
-
 class LogsGrokParser(ModelNormal):
     validations = {
         "samples": {
@@ -26,7 +18,9 @@ class LogsGrokParser(ModelNormal):
 
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.logs_grok_parser_rules import LogsGrokParserRules
+        from datadog_api_client.v1.model.logs_grok_parser_type import LogsGrokParserType
+
         return {
             "grok": (LogsGrokParserRules,),
             "is_enabled": (bool,),
@@ -47,8 +41,8 @@ class LogsGrokParser(ModelNormal):
 
     def __init__(self, grok, type, *args, **kwargs):
         """
-        Create custom grok rules to parse the full message or [a specific attribute of your raw event](https://docs.datadoghq.com/logs/log_configuration/parsing/#advanced-settings).
-        For more information, see the [parsing section](https://docs.datadoghq.com/logs/log_configuration/parsing).
+        Create custom grok rules to parse the full message or `a specific attribute of your raw event <https://docs.datadoghq.com/logs/log_configuration/parsing/#advanced-settings>`_.
+        For more information, see the `parsing section <https://docs.datadoghq.com/logs/log_configuration/parsing>`_.
 
         :param grok: Set of rules for the grok parser.
         :type grok: LogsGrokParserRules
