@@ -10,16 +10,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.logs_pipeline import LogsPipeline
-
-    globals()["LogsPipeline"] = LogsPipeline
-
-
 class LogsPipelineList(ModelSimple):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.logs_pipeline import LogsPipeline
+
         return {
             "value": ([LogsPipeline],),
         }
@@ -30,7 +25,6 @@ class LogsPipelineList(ModelSimple):
 
         Note that value can be passed either in args or in kwargs, but not in both.
 
-        :param value: Array of pipeline ID strings.
         :type value: [LogsPipeline]
         """
         super().__init__(kwargs)
