@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class LogsQueryCompute(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "aggregation": (str,),
             "facet": (str,),
@@ -27,8 +24,6 @@ class LogsQueryCompute(ModelNormal):
         "interval": "interval",
     }
 
-    read_only_vars = {}
-
     def __init__(self, aggregation, *args, **kwargs):
         """
         Define computation for a log query.
