@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.logs_trace_remapper_type import LogsTraceRemapperType
-
-    globals()["LogsTraceRemapperType"] = LogsTraceRemapperType
-
-
 class LogsTraceRemapper(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.logs_trace_remapper_type import LogsTraceRemapperType
+
         return {
             "is_enabled": (bool,),
             "name": (str,),
@@ -37,10 +32,13 @@ class LogsTraceRemapper(ModelNormal):
         """
         There are two ways to improve correlation between application traces and logs.
 
-          1. Follow the documentation on [how to inject a trace ID in the application logs](https://docs.datadoghq.com/tracing/connect_logs_and_traces)
-          and by default log integrations take care of all the rest of the setup.
 
-          2. Use the Trace remapper processor to define a log attribute as its associated trace ID.
+        #.
+           Follow the documentation on `how to inject a trace ID in the application logs <https://docs.datadoghq.com/tracing/connect_logs_and_traces>`_
+           and by default log integrations take care of all the rest of the setup.
+
+        #.
+           Use the Trace remapper processor to define a log attribute as its associated trace ID.
 
         :param is_enabled: Whether or not the processor is enabled.
         :type is_enabled: bool, optional
