@@ -10,16 +10,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.logs_url_parser_type import LogsURLParserType
-
-    globals()["LogsURLParserType"] = LogsURLParserType
-
-
 class LogsURLParser(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.logs_url_parser_type import LogsURLParserType
+
         return {
             "is_enabled": (bool,),
             "name": (str,),
@@ -54,7 +49,7 @@ class LogsURLParser(ModelNormal):
         :param sources: Array of source attributes.
         :type sources: [str]
 
-        :param target: Name of the parent attribute that contains all the extracted details from the `sources`.
+        :param target: Name of the parent attribute that contains all the extracted details from the ``sources``.
         :type target: str
 
         :param type: Type of logs URL parser.
