@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.monitor_state_group import MonitorStateGroup
-
-    globals()["MonitorStateGroup"] = MonitorStateGroup
-
-
 class MonitorState(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.monitor_state_group import MonitorStateGroup
+
         return {
             "groups": ({str: (MonitorStateGroup,)},),
         }
