@@ -11,20 +11,6 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.creator import Creator
-    from datadog_api_client.v1.model.monitor_options import MonitorOptions
-    from datadog_api_client.v1.model.monitor_overall_states import MonitorOverallStates
-    from datadog_api_client.v1.model.monitor_state import MonitorState
-    from datadog_api_client.v1.model.monitor_type import MonitorType
-
-    globals()["Creator"] = Creator
-    globals()["MonitorOptions"] = MonitorOptions
-    globals()["MonitorOverallStates"] = MonitorOverallStates
-    globals()["MonitorState"] = MonitorState
-    globals()["MonitorType"] = MonitorType
-
-
 class MonitorUpdateRequest(ModelNormal):
     validations = {
         "priority": {
@@ -35,7 +21,12 @@ class MonitorUpdateRequest(ModelNormal):
 
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.creator import Creator
+        from datadog_api_client.v1.model.monitor_options import MonitorOptions
+        from datadog_api_client.v1.model.monitor_overall_states import MonitorOverallStates
+        from datadog_api_client.v1.model.monitor_state import MonitorState
+        from datadog_api_client.v1.model.monitor_type import MonitorType
+
         return {
             "created": (datetime,),
             "creator": (Creator,),
@@ -94,7 +85,7 @@ class MonitorUpdateRequest(ModelNormal):
         :param creator: Object describing the creator of the shared element.
         :type creator: Creator, optional
 
-        :param deleted: Whether or not the monitor is deleted. (Always `null`)
+        :param deleted: Whether or not the monitor is deleted. (Always ``null`` )
         :type deleted: datetime, none_type, optional
 
         :param id: ID of this monitor.
@@ -124,7 +115,7 @@ class MonitorUpdateRequest(ModelNormal):
         :param query: The monitor query.
         :type query: str, optional
 
-        :param restricted_roles: A list of unique role identifiers to define which roles are allowed to edit the monitor. The unique identifiers for all roles can be pulled from the [Roles API](https://docs.datadoghq.com/api/latest/roles/#list-roles) and are located in the `data.id` field. Editing a monitor includes any updates to the monitor configuration, monitor deletion, and muting of the monitor for any amount of time. `restricted_roles` is the successor of `locked`. For more information about `locked` and `restricted_roles`, see the [monitor options docs](https://docs.datadoghq.com/monitors/guide/monitor_api_options/#permissions-options).
+        :param restricted_roles: A list of unique role identifiers to define which roles are allowed to edit the monitor. The unique identifiers for all roles can be pulled from the `Roles API <https://docs.datadoghq.com/api/latest/roles/#list-roles>`_ and are located in the ``data.id`` field. Editing a monitor includes any updates to the monitor configuration, monitor deletion, and muting of the monitor for any amount of time. ``restricted_roles`` is the successor of ``locked``. For more information about ``locked`` and ``restricted_roles`` , see the `monitor options docs <https://docs.datadoghq.com/monitors/guide/monitor_api_options/#permissions-options>`_.
         :type restricted_roles: [str], optional
 
         :param state: Wrapper object with the different monitor states.
@@ -133,7 +124,7 @@ class MonitorUpdateRequest(ModelNormal):
         :param tags: Tags associated to your monitor.
         :type tags: [str], optional
 
-        :param type: The type of the monitor. For more information about `type`, see the [monitor options](https://docs.datadoghq.com/monitors/guide/monitor_api_options/) docs.
+        :param type: The type of the monitor. For more information about ``type`` , see the `monitor options <https://docs.datadoghq.com/monitors/guide/monitor_api_options/>`_ docs.
         :type type: MonitorType, optional
         """
         super().__init__(kwargs)
