@@ -17,6 +17,8 @@ class MonthlyUsageAttributionValues(ModelNormal):
             "api_usage": (float,),
             "apm_host_percentage": (float,),
             "apm_host_usage": (float,),
+            "appsec_percentage": (float,),
+            "appsec_usage": (float,),
             "browser_percentage": (float,),
             "browser_usage": (float,),
             "container_percentage": (float,),
@@ -25,6 +27,10 @@ class MonthlyUsageAttributionValues(ModelNormal):
             "custom_timeseries_usage": (float,),
             "estimated_indexed_logs_percentage": (float,),
             "estimated_indexed_logs_usage": (float,),
+            "estimated_indexed_spans_percentage": (float,),
+            "estimated_indexed_spans_usage": (float,),
+            "estimated_ingested_spans_percentage": (float,),
+            "estimated_ingested_spans_usage": (float,),
             "fargate_percentage": (float,),
             "fargate_usage": (float,),
             "functions_percentage": (float,),
@@ -50,6 +56,8 @@ class MonthlyUsageAttributionValues(ModelNormal):
         "api_usage": "api_usage",
         "apm_host_percentage": "apm_host_percentage",
         "apm_host_usage": "apm_host_usage",
+        "appsec_percentage": "appsec_percentage",
+        "appsec_usage": "appsec_usage",
         "browser_percentage": "browser_percentage",
         "browser_usage": "browser_usage",
         "container_percentage": "container_percentage",
@@ -58,6 +66,10 @@ class MonthlyUsageAttributionValues(ModelNormal):
         "custom_timeseries_usage": "custom_timeseries_usage",
         "estimated_indexed_logs_percentage": "estimated_indexed_logs_percentage",
         "estimated_indexed_logs_usage": "estimated_indexed_logs_usage",
+        "estimated_indexed_spans_percentage": "estimated_indexed_spans_percentage",
+        "estimated_indexed_spans_usage": "estimated_indexed_spans_usage",
+        "estimated_ingested_spans_percentage": "estimated_ingested_spans_percentage",
+        "estimated_ingested_spans_usage": "estimated_ingested_spans_usage",
         "fargate_percentage": "fargate_percentage",
         "fargate_usage": "fargate_usage",
         "functions_percentage": "functions_percentage",
@@ -94,6 +106,12 @@ class MonthlyUsageAttributionValues(ModelNormal):
         :param apm_host_usage: The APM host usage by tag(s).
         :type apm_host_usage: float, optional
 
+        :param appsec_percentage: The percentage of Application Security Monitoring host usage by tag(s).
+        :type appsec_percentage: float, optional
+
+        :param appsec_usage: The Application Security Monitoring host usage by tag(s).
+        :type appsec_usage: float, optional
+
         :param browser_percentage: The percentage of synthetic browser test usage by tag(s).
         :type browser_percentage: float, optional
 
@@ -118,6 +136,18 @@ class MonthlyUsageAttributionValues(ModelNormal):
         :param estimated_indexed_logs_usage: The estimated live indexed logs usage by tag(s). This field is in private beta.
         :type estimated_indexed_logs_usage: float, optional
 
+        :param estimated_indexed_spans_percentage: The percentage of estimated indexed spans usage by tag(s). This field is in private beta.
+        :type estimated_indexed_spans_percentage: float, optional
+
+        :param estimated_indexed_spans_usage: The estimated indexed spans usage by tag(s). This field is in private beta.
+        :type estimated_indexed_spans_usage: float, optional
+
+        :param estimated_ingested_spans_percentage: The percentage of estimated ingested spans usage by tag(s). This field is in private beta.
+        :type estimated_ingested_spans_percentage: float, optional
+
+        :param estimated_ingested_spans_usage: The estimated ingested spans usage by tag(s). This field is in private beta.
+        :type estimated_ingested_spans_usage: float, optional
+
         :param fargate_percentage: The percentage of Fargate usage by tags.
         :type fargate_percentage: float, optional
 
