@@ -3,7 +3,7 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
     datetime,
@@ -11,11 +11,8 @@ from datadog_api_client.v1.model_utils import (
 
 
 class NotebookAbsoluteTime(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "end": (datetime,),
             "live": (bool,),
@@ -28,8 +25,6 @@ class NotebookAbsoluteTime(ModelNormal):
         "start": "start",
     }
 
-    read_only_vars = {}
-
     def __init__(self, end, start, *args, **kwargs):
         """
         Absolute timeframe.
