@@ -9,22 +9,14 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.distribution_widget_definition import DistributionWidgetDefinition
-    from datadog_api_client.v1.model.notebook_graph_size import NotebookGraphSize
-    from datadog_api_client.v1.model.notebook_split_by import NotebookSplitBy
-    from datadog_api_client.v1.model.notebook_cell_time import NotebookCellTime
-
-    globals()["DistributionWidgetDefinition"] = DistributionWidgetDefinition
-    globals()["NotebookGraphSize"] = NotebookGraphSize
-    globals()["NotebookSplitBy"] = NotebookSplitBy
-    globals()["NotebookCellTime"] = NotebookCellTime
-
-
 class NotebookDistributionCellAttributes(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.distribution_widget_definition import DistributionWidgetDefinition
+        from datadog_api_client.v1.model.notebook_graph_size import NotebookGraphSize
+        from datadog_api_client.v1.model.notebook_split_by import NotebookSplitBy
+        from datadog_api_client.v1.model.notebook_cell_time import NotebookCellTime
+
         return {
             "definition": (DistributionWidgetDefinition,),
             "graph_size": (NotebookGraphSize,),
@@ -41,7 +33,7 @@ class NotebookDistributionCellAttributes(ModelNormal):
 
     def __init__(self, definition, *args, **kwargs):
         """
-        The attributes of a notebook `distribution` cell.
+        The attributes of a notebook ``distribution`` cell.
 
         :param definition: The Distribution visualization is another way of showing metrics
             aggregated across one or several tags, such as hosts.
