@@ -25,7 +25,7 @@ class OrganizationSettingsSamlStrictMode(ModelNormal):
         Has one property enabled (boolean).
 
         :param enabled: Whether or not the SAML strict mode is enabled. If true, all users must log in with SAML.
-            Learn more on the [SAML Strict documentation](https://docs.datadoghq.com/account_management/saml/#saml-strict).
+            Learn more on the `SAML Strict documentation <https://docs.datadoghq.com/account_management/saml/#saml-strict>`_.
         :type enabled: bool, optional
         """
         super().__init__(kwargs)
