@@ -9,28 +9,18 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
-    from datadog_api_client.v1.model.scatter_plot_widget_definition_requests import ScatterPlotWidgetDefinitionRequests
-    from datadog_api_client.v1.model.widget_time import WidgetTime
-    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
-    from datadog_api_client.v1.model.scatter_plot_widget_definition_type import ScatterPlotWidgetDefinitionType
-    from datadog_api_client.v1.model.widget_axis import WidgetAxis
-    from datadog_api_client.v1.model.widget_axis import WidgetAxis
-
-    globals()["WidgetCustomLink"] = WidgetCustomLink
-    globals()["ScatterPlotWidgetDefinitionRequests"] = ScatterPlotWidgetDefinitionRequests
-    globals()["WidgetTime"] = WidgetTime
-    globals()["WidgetTextAlign"] = WidgetTextAlign
-    globals()["ScatterPlotWidgetDefinitionType"] = ScatterPlotWidgetDefinitionType
-    globals()["WidgetAxis"] = WidgetAxis
-    globals()["WidgetAxis"] = WidgetAxis
-
-
 class ScatterPlotWidgetDefinition(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.widget_custom_link import WidgetCustomLink
+        from datadog_api_client.v1.model.scatter_plot_widget_definition_requests import (
+            ScatterPlotWidgetDefinitionRequests,
+        )
+        from datadog_api_client.v1.model.widget_time import WidgetTime
+        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
+        from datadog_api_client.v1.model.scatter_plot_widget_definition_type import ScatterPlotWidgetDefinitionType
+        from datadog_api_client.v1.model.widget_axis import WidgetAxis
+
         return {
             "color_by_groups": ([str],),
             "custom_links": ([WidgetCustomLink],),
