@@ -24,7 +24,7 @@ class ServiceLevelObjectiveQuery(ModelNormal):
 
     def __init__(self, denominator, numerator, *args, **kwargs):
         """
-        A metric SLI query. **Required if type is `metric`**. Note that Datadog only allows the sum by aggregator
+        A metric-based SLO. **Required if type is metric**. Note that Datadog only allows the sum by aggregator
         to be used because this will sum up all request counts instead of averaging them, or taking the max or
         min of all of those requests.
 
