@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class SLOHistoryResponseError(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "error": (str,),
         }
@@ -23,8 +20,6 @@ class SLOHistoryResponseError(ModelNormal):
         "error": "error",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         A list of errors while querying the history data for the service level objective.
