@@ -3,23 +3,22 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelSimple,
     cached_property,
 )
 
 
 class SyntheticsAPIStepSubtype(ModelSimple):
+
     allowed_values = {
         "value": {
             "HTTP": "http",
         },
     }
 
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "value": (str,),
         }
