@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.synthetics_basic_auth_ntlm_type import SyntheticsBasicAuthNTLMType
-
-    globals()["SyntheticsBasicAuthNTLMType"] = SyntheticsBasicAuthNTLMType
-
-
 class SyntheticsBasicAuthNTLM(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.synthetics_basic_auth_ntlm_type import SyntheticsBasicAuthNTLMType
+
         return {
             "domain": (str,),
             "password": (str,),
@@ -37,7 +32,7 @@ class SyntheticsBasicAuthNTLM(ModelNormal):
 
     def __init__(self, type, *args, **kwargs):
         """
-        Object to handle `NTLM` authentication when performing the test.
+        Object to handle ``NTLM`` authentication when performing the test.
 
         :param domain: Domain for the authentication to use when performing the test.
         :type domain: str, optional
