@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.synthetics_batch_details_data import SyntheticsBatchDetailsData
-
-    globals()["SyntheticsBatchDetailsData"] = SyntheticsBatchDetailsData
-
-
 class SyntheticsBatchDetails(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.synthetics_batch_details_data import SyntheticsBatchDetailsData
+
         return {
             "data": (SyntheticsBatchDetailsData,),
         }
