@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.synthetics_browser_test_failure_code import SyntheticsBrowserTestFailureCode
-
-    globals()["SyntheticsBrowserTestFailureCode"] = SyntheticsBrowserTestFailureCode
-
-
 class SyntheticsBrowserTestResultFailure(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.synthetics_browser_test_failure_code import SyntheticsBrowserTestFailureCode
+
         return {
             "code": (SyntheticsBrowserTestFailureCode,),
             "message": (str,),
