@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.synthetics_device_id import SyntheticsDeviceID
-
-    globals()["SyntheticsDeviceID"] = SyntheticsDeviceID
-
-
 class SyntheticsDevice(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.synthetics_device_id import SyntheticsDeviceID
+
         return {
             "height": (int,),
             "id": (SyntheticsDeviceID,),
