@@ -9,20 +9,14 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.synthetics_variable_parser import SyntheticsVariableParser
-    from datadog_api_client.v1.model.synthetics_global_variable_parse_test_options_type import (
-        SyntheticsGlobalVariableParseTestOptionsType,
-    )
-
-    globals()["SyntheticsVariableParser"] = SyntheticsVariableParser
-    globals()["SyntheticsGlobalVariableParseTestOptionsType"] = SyntheticsGlobalVariableParseTestOptionsType
-
-
 class SyntheticsGlobalVariableParseTestOptions(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.synthetics_variable_parser import SyntheticsVariableParser
+        from datadog_api_client.v1.model.synthetics_global_variable_parse_test_options_type import (
+            SyntheticsGlobalVariableParseTestOptionsType,
+        )
+
         return {
             "field": (str,),
             "parser": (SyntheticsVariableParser,),
@@ -37,9 +31,9 @@ class SyntheticsGlobalVariableParseTestOptions(ModelNormal):
 
     def __init__(self, parser, type, *args, **kwargs):
         """
-        Parser options to use for retrieving a Synthetics global variable from a Synthetics Test. Used in conjunction with `parse_test_public_id`.
+        Parser options to use for retrieving a Synthetics global variable from a Synthetics Test. Used in conjunction with ``parse_test_public_id``.
 
-        :param field: When type is `http_header`, name of the header to use to extract the value.
+        :param field: When type is ``http_header`` , name of the header to use to extract the value.
         :type field: str, optional
 
         :param parser: Details of the parser to use for the global variable.
