@@ -3,14 +3,13 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class SyntheticsTestOptionsMonitorOptions(ModelNormal):
-
     validations = {
         "renotify_interval": {
             "inclusive_maximum": 1440,
@@ -19,7 +18,7 @@ class SyntheticsTestOptionsMonitorOptions(ModelNormal):
     }
 
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "renotify_interval": (int,),
         }
@@ -28,8 +27,6 @@ class SyntheticsTestOptionsMonitorOptions(ModelNormal):
         "renotify_interval": "renotify_interval",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Object containing the options for a Synthetic test as a monitor
