@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v1.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class SyntheticsTestOptionsRetry(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "count": (int,),
             "interval": (float,),
@@ -25,8 +22,6 @@ class SyntheticsTestOptionsRetry(ModelNormal):
         "interval": "interval",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Object describing the retry strategy to apply to a Synthetic test.
