@@ -9,20 +9,6 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.synthetics_basic_auth import SyntheticsBasicAuth
-    from datadog_api_client.v1.model.synthetics_test_request_certificate import SyntheticsTestRequestCertificate
-    from datadog_api_client.v1.model.synthetics_test_headers import SyntheticsTestHeaders
-    from datadog_api_client.v1.model.http_method import HTTPMethod
-    from datadog_api_client.v1.model.synthetics_test_request_proxy import SyntheticsTestRequestProxy
-
-    globals()["SyntheticsBasicAuth"] = SyntheticsBasicAuth
-    globals()["SyntheticsTestRequestCertificate"] = SyntheticsTestRequestCertificate
-    globals()["SyntheticsTestHeaders"] = SyntheticsTestHeaders
-    globals()["HTTPMethod"] = HTTPMethod
-    globals()["SyntheticsTestRequestProxy"] = SyntheticsTestRequestProxy
-
-
 class SyntheticsTestRequest(ModelNormal):
     validations = {
         "dns_server_port": {
@@ -37,7 +23,13 @@ class SyntheticsTestRequest(ModelNormal):
 
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.synthetics_basic_auth import SyntheticsBasicAuth
+        from datadog_api_client.v1.model.synthetics_test_request_certificate import SyntheticsTestRequestCertificate
+        from datadog_api_client.v1.model.synthetics_test_headers import SyntheticsTestHeaders
+        from datadog_api_client.v1.model.synthetics_test_metadata import SyntheticsTestMetadata
+        from datadog_api_client.v1.model.http_method import HTTPMethod
+        from datadog_api_client.v1.model.synthetics_test_request_proxy import SyntheticsTestRequestProxy
+
         return {
             "allow_insecure": (bool,),
             "basic_auth": (SyntheticsBasicAuth,),
@@ -49,6 +41,7 @@ class SyntheticsTestRequest(ModelNormal):
             "headers": (SyntheticsTestHeaders,),
             "host": (str,),
             "message": (str,),
+            "metadata": (SyntheticsTestMetadata,),
             "method": (HTTPMethod,),
             "no_saving_response_body": (bool,),
             "number_of_packets": (int,),
@@ -56,6 +49,7 @@ class SyntheticsTestRequest(ModelNormal):
             "proxy": (SyntheticsTestRequestProxy,),
             "query": (dict,),
             "servername": (str,),
+            "service": (str,),
             "should_track_hops": (bool,),
             "timeout": (float,),
             "url": (str,),
@@ -72,6 +66,7 @@ class SyntheticsTestRequest(ModelNormal):
         "headers": "headers",
         "host": "host",
         "message": "message",
+        "metadata": "metadata",
         "method": "method",
         "no_saving_response_body": "noSavingResponseBody",
         "number_of_packets": "numberOfPackets",
@@ -79,6 +74,7 @@ class SyntheticsTestRequest(ModelNormal):
         "proxy": "proxy",
         "query": "query",
         "servername": "servername",
+        "service": "service",
         "should_track_hops": "shouldTrackHops",
         "timeout": "timeout",
         "url": "url",
@@ -118,6 +114,9 @@ class SyntheticsTestRequest(ModelNormal):
         :param message: Message to send for UDP or WebSocket tests.
         :type message: str, optional
 
+        :param metadata: Metadata to include when performing the gRPC test.
+        :type metadata: SyntheticsTestMetadata, optional
+
         :param method: The HTTP method.
         :type method: HTTPMethod, optional
 
@@ -141,6 +140,9 @@ class SyntheticsTestRequest(ModelNormal):
             the same IP address and TCP port number.
         :type servername: str, optional
 
+        :param service: gRPC service on which you want to perform the healthcheck.
+        :type service: str, optional
+
         :param should_track_hops: Turns on a traceroute probe to discover all gateways along the path to the host destination.
         :type should_track_hops: bool, optional
 
