@@ -9,46 +9,20 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.widget_aggregator import WidgetAggregator
-    from datadog_api_client.v1.model.log_query_definition import LogQueryDefinition
-    from datadog_api_client.v1.model.apm_stats_query_definition import ApmStatsQueryDefinition
-    from datadog_api_client.v1.model.table_widget_cell_display_mode import TableWidgetCellDisplayMode
-    from datadog_api_client.v1.model.widget_conditional_format import WidgetConditionalFormat
-    from datadog_api_client.v1.model.log_query_definition import LogQueryDefinition
-    from datadog_api_client.v1.model.widget_formula import WidgetFormula
-    from datadog_api_client.v1.model.log_query_definition import LogQueryDefinition
-    from datadog_api_client.v1.model.log_query_definition import LogQueryDefinition
-    from datadog_api_client.v1.model.widget_sort import WidgetSort
-    from datadog_api_client.v1.model.process_query_definition import ProcessQueryDefinition
-    from datadog_api_client.v1.model.log_query_definition import LogQueryDefinition
-    from datadog_api_client.v1.model.formula_and_function_query_definition import FormulaAndFunctionQueryDefinition
-    from datadog_api_client.v1.model.formula_and_function_response_format import FormulaAndFunctionResponseFormat
-    from datadog_api_client.v1.model.log_query_definition import LogQueryDefinition
-    from datadog_api_client.v1.model.log_query_definition import LogQueryDefinition
-
-    globals()["WidgetAggregator"] = WidgetAggregator
-    globals()["LogQueryDefinition"] = LogQueryDefinition
-    globals()["ApmStatsQueryDefinition"] = ApmStatsQueryDefinition
-    globals()["TableWidgetCellDisplayMode"] = TableWidgetCellDisplayMode
-    globals()["WidgetConditionalFormat"] = WidgetConditionalFormat
-    globals()["LogQueryDefinition"] = LogQueryDefinition
-    globals()["WidgetFormula"] = WidgetFormula
-    globals()["LogQueryDefinition"] = LogQueryDefinition
-    globals()["LogQueryDefinition"] = LogQueryDefinition
-    globals()["WidgetSort"] = WidgetSort
-    globals()["ProcessQueryDefinition"] = ProcessQueryDefinition
-    globals()["LogQueryDefinition"] = LogQueryDefinition
-    globals()["FormulaAndFunctionQueryDefinition"] = FormulaAndFunctionQueryDefinition
-    globals()["FormulaAndFunctionResponseFormat"] = FormulaAndFunctionResponseFormat
-    globals()["LogQueryDefinition"] = LogQueryDefinition
-    globals()["LogQueryDefinition"] = LogQueryDefinition
-
-
 class TableWidgetRequest(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.widget_aggregator import WidgetAggregator
+        from datadog_api_client.v1.model.log_query_definition import LogQueryDefinition
+        from datadog_api_client.v1.model.apm_stats_query_definition import ApmStatsQueryDefinition
+        from datadog_api_client.v1.model.table_widget_cell_display_mode import TableWidgetCellDisplayMode
+        from datadog_api_client.v1.model.widget_conditional_format import WidgetConditionalFormat
+        from datadog_api_client.v1.model.widget_formula import WidgetFormula
+        from datadog_api_client.v1.model.widget_sort import WidgetSort
+        from datadog_api_client.v1.model.process_query_definition import ProcessQueryDefinition
+        from datadog_api_client.v1.model.formula_and_function_query_definition import FormulaAndFunctionQueryDefinition
+        from datadog_api_client.v1.model.formula_and_function_response_format import FormulaAndFunctionResponseFormat
+
         return {
             "aggregator": (WidgetAggregator,),
             "alias": (str,),
