@@ -27,7 +27,7 @@ class TreeMapSizeBy(ModelSimple):
 
     def __init__(self, *args, **kwargs):
         """
-        The attribute used to determine size in the widget.
+        (deprecated) The attribute formerly used to determine size in the widget.
 
         Note that value can be passed either in args or in kwargs, but not in both.
 
