@@ -17,6 +17,8 @@ class UsageAttributionSort(ModelSimple):
             "SNMP_USAGE": "snmp_usage",
             "APM_HOST_USAGE": "apm_host_usage",
             "API_USAGE": "api_usage",
+            "APPSEC_USAGE": "appsec_usage",
+            "APPSEC_PERCENTAGE": "appsec_percentage",
             "CONTAINER_USAGE": "container_usage",
             "CUSTOM_TIMESERIES_PERCENTAGE": "custom_timeseries_percentage",
             "CONTAINER_PERCENTAGE": "container_percentage",
@@ -35,6 +37,10 @@ class UsageAttributionSort(ModelSimple):
             "LAMBDA_INVOCATIONS_PERCENTAGE": "lambda_invocations_percentage",
             "ESTIMATED_INDEXED_LOGS_USAGE": "estimated_indexed_logs_usage",
             "ESTIMATED_INDEXED_LOGS_PERCENTAGE": "estimated_indexed_logs_percentage",
+            "ESTIMATED_INDEXED_SPANS_USAGE": "estimated_indexed_spans_usage",
+            "ESTIMATED_INDEXED_SPANS_PERCENTAGE": "estimated_indexed_spans_percentage",
+            "ESTIMATED_INGESTED_SPANS_USAGE": "estimated_ingested_spans_usage",
+            "ESTIMATED_INGESTED_SPANS_PERCENTAGE": "estimated_ingested_spans_percentage",
         },
     }
 
@@ -50,7 +56,7 @@ class UsageAttributionSort(ModelSimple):
 
         Note that value can be passed either in args or in kwargs, but not in both.
 
-        :param value: If omitted defaults to "custom_timeseries_usage". Must be one of ["api_percentage", "snmp_usage", "apm_host_usage", "api_usage", "container_usage", "custom_timeseries_percentage", "container_percentage", "apm_host_percentage", "npm_host_percentage", "browser_percentage", "browser_usage", "infra_host_percentage", "snmp_percentage", "npm_host_usage", "infra_host_usage", "custom_timeseries_usage", "lambda_functions_usage", "lambda_functions_percentage", "lambda_invocations_usage", "lambda_invocations_percentage", "estimated_indexed_logs_usage", "estimated_indexed_logs_percentage"].
+        :param value: If omitted defaults to "custom_timeseries_usage". Must be one of ["api_percentage", "snmp_usage", "apm_host_usage", "api_usage", "appsec_usage", "appsec_percentage", "container_usage", "custom_timeseries_percentage", "container_percentage", "apm_host_percentage", "npm_host_percentage", "browser_percentage", "browser_usage", "infra_host_percentage", "snmp_percentage", "npm_host_usage", "infra_host_usage", "custom_timeseries_usage", "lambda_functions_usage", "lambda_functions_percentage", "lambda_invocations_usage", "lambda_invocations_percentage", "estimated_indexed_logs_usage", "estimated_indexed_logs_percentage", "estimated_indexed_spans_usage", "estimated_indexed_spans_percentage", "estimated_ingested_spans_usage", "estimated_ingested_spans_percentage"].
         :type value: str
         """
         super().__init__(kwargs)
