@@ -17,6 +17,8 @@ class UsageAttributionValues(ModelNormal):
             "api_usage": (float,),
             "apm_host_percentage": (float,),
             "apm_host_usage": (float,),
+            "appsec_percentage": (float,),
+            "appsec_usage": (float,),
             "browser_percentage": (float,),
             "browser_usage": (float,),
             "container_percentage": (float,),
@@ -37,6 +39,10 @@ class UsageAttributionValues(ModelNormal):
             "dbm_queries_usage": (float,),
             "estimated_indexed_logs_percentage": (float,),
             "estimated_indexed_logs_usage": (float,),
+            "estimated_indexed_spans_percentage": (float,),
+            "estimated_indexed_spans_usage": (float,),
+            "estimated_ingested_spans_percentage": (float,),
+            "estimated_ingested_spans_usage": (float,),
             "infra_host_percentage": (float,),
             "infra_host_usage": (float,),
             "lambda_functions_percentage": (float,),
@@ -58,6 +64,8 @@ class UsageAttributionValues(ModelNormal):
         "api_usage": "api_usage",
         "apm_host_percentage": "apm_host_percentage",
         "apm_host_usage": "apm_host_usage",
+        "appsec_percentage": "appsec_percentage",
+        "appsec_usage": "appsec_usage",
         "browser_percentage": "browser_percentage",
         "browser_usage": "browser_usage",
         "container_percentage": "container_percentage",
@@ -78,6 +86,10 @@ class UsageAttributionValues(ModelNormal):
         "dbm_queries_usage": "dbm_queries_usage",
         "estimated_indexed_logs_percentage": "estimated_indexed_logs_percentage",
         "estimated_indexed_logs_usage": "estimated_indexed_logs_usage",
+        "estimated_indexed_spans_percentage": "estimated_indexed_spans_percentage",
+        "estimated_indexed_spans_usage": "estimated_indexed_spans_usage",
+        "estimated_ingested_spans_percentage": "estimated_ingested_spans_percentage",
+        "estimated_ingested_spans_usage": "estimated_ingested_spans_usage",
         "infra_host_percentage": "infra_host_percentage",
         "infra_host_usage": "infra_host_usage",
         "lambda_functions_percentage": "lambda_functions_percentage",
@@ -110,6 +122,12 @@ class UsageAttributionValues(ModelNormal):
         :param apm_host_usage: The APM host usage by tag(s).
         :type apm_host_usage: float, optional
 
+        :param appsec_percentage: The percentage of Application Security Monitoring host usage by tag(s).
+        :type appsec_percentage: float, optional
+
+        :param appsec_usage: The Application Security Monitoring host usage by tag(s).
+        :type appsec_usage: float, optional
+
         :param browser_percentage: The percentage of synthetic browser test usage by tag(s).
         :type browser_percentage: float, optional
 
@@ -170,6 +188,18 @@ class UsageAttributionValues(ModelNormal):
         :param estimated_indexed_logs_usage: The estimated live indexed logs usage by tag(s). Note this field is in private beta.
         :type estimated_indexed_logs_usage: float, optional
 
+        :param estimated_indexed_spans_percentage: The percentage of estimated indexed spans usage by tag(s). Note this field is in private beta.
+        :type estimated_indexed_spans_percentage: float, optional
+
+        :param estimated_indexed_spans_usage: The estimated indexed spans usage by tag(s). Note this field is in private beta.
+        :type estimated_indexed_spans_usage: float, optional
+
+        :param estimated_ingested_spans_percentage: The percentage of estimated ingested spans usage by tag(s). Note this field is in private beta.
+        :type estimated_ingested_spans_percentage: float, optional
+
+        :param estimated_ingested_spans_usage: The estimated ingested spans usage by tag(s). Note this field is in private beta.
+        :type estimated_ingested_spans_usage: float, optional
+
         :param infra_host_percentage: The percentage of infrastructure host usage by tag(s).
         :type infra_host_percentage: float, optional
 
