@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.usage_ci_visibility_hour import UsageCIVisibilityHour
-
-    globals()["UsageCIVisibilityHour"] = UsageCIVisibilityHour
-
-
 class UsageCIVisibilityResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.usage_ci_visibility_hour import UsageCIVisibilityHour
+
         return {
             "usage": ([UsageCIVisibilityHour],),
         }
