@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.usage_logs_by_retention_hour import UsageLogsByRetentionHour
-
-    globals()["UsageLogsByRetentionHour"] = UsageLogsByRetentionHour
-
-
 class UsageLogsByRetentionResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.usage_logs_by_retention_hour import UsageLogsByRetentionHour
+
         return {
             "usage": ([UsageLogsByRetentionHour],),
         }
