@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.usage_rum_units_hour import UsageRumUnitsHour
-
-    globals()["UsageRumUnitsHour"] = UsageRumUnitsHour
-
-
 class UsageRumUnitsResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.usage_rum_units_hour import UsageRumUnitsHour
+
         return {
             "usage": ([UsageRumUnitsHour],),
         }
