@@ -10,18 +10,12 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.logs_by_retention import LogsByRetention
-    from datadog_api_client.v1.model.usage_summary_date import UsageSummaryDate
-
-    globals()["LogsByRetention"] = LogsByRetention
-    globals()["UsageSummaryDate"] = UsageSummaryDate
-
-
 class UsageSummaryResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.logs_by_retention import LogsByRetention
+        from datadog_api_client.v1.model.usage_summary_date import UsageSummaryDate
+
         return {
             "agent_host_top99p_sum": (int,),
             "apm_azure_app_service_host_top99p_sum": (int,),
@@ -72,6 +66,7 @@ class UsageSummaryResponse(ModelNormal):
             "mobile_rum_session_count_agg_sum": (int,),
             "mobile_rum_session_count_android_agg_sum": (int,),
             "mobile_rum_session_count_ios_agg_sum": (int,),
+            "mobile_rum_session_count_reactnative_agg_sum": (int,),
             "mobile_rum_units_agg_sum": (int,),
             "netflow_indexed_events_count_agg_sum": (int,),
             "npm_host_top99p_sum": (int,),
@@ -147,6 +142,7 @@ class UsageSummaryResponse(ModelNormal):
         "mobile_rum_session_count_agg_sum": "mobile_rum_session_count_agg_sum",
         "mobile_rum_session_count_android_agg_sum": "mobile_rum_session_count_android_agg_sum",
         "mobile_rum_session_count_ios_agg_sum": "mobile_rum_session_count_ios_agg_sum",
+        "mobile_rum_session_count_reactnative_agg_sum": "mobile_rum_session_count_reactnative_agg_sum",
         "mobile_rum_units_agg_sum": "mobile_rum_units_agg_sum",
         "netflow_indexed_events_count_agg_sum": "netflow_indexed_events_count_agg_sum",
         "npm_host_top99p_sum": "npm_host_top99p_sum",
@@ -323,6 +319,9 @@ class UsageSummaryResponse(ModelNormal):
         :param mobile_rum_session_count_ios_agg_sum: Shows the sum of all mobile RUM Sessions on iOS over all hours in the current months for all organizations.
         :type mobile_rum_session_count_ios_agg_sum: int, optional
 
+        :param mobile_rum_session_count_reactnative_agg_sum: Shows the sum of all mobile RUM Sessions on React Native over all hours in the current months for all organizations.
+        :type mobile_rum_session_count_reactnative_agg_sum: int, optional
+
         :param mobile_rum_units_agg_sum: Shows the sum of all mobile RUM units over all hours in the current months for all organizations.
         :type mobile_rum_units_agg_sum: int, optional
 
