@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v1.model.query_sort_order import QuerySortOrder
-
-    globals()["QuerySortOrder"] = QuerySortOrder
-
-
 class WidgetFormulaLimit(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v1.model.query_sort_order import QuerySortOrder
+
         return {
             "count": (int,),
             "order": (QuerySortOrder,),
