@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class CloudWorkloadSecurityAgentRuleUpdateAttributes(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "description": (str,),
             "enabled": (bool,),
@@ -27,8 +24,6 @@ class CloudWorkloadSecurityAgentRuleUpdateAttributes(ModelNormal):
         "expression": "expression",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Update an existing Cloud Workload Security Agent rule.
