@@ -9,16 +9,13 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.cloud_workload_security_agent_rule_data import CloudWorkloadSecurityAgentRuleData
-
-    globals()["CloudWorkloadSecurityAgentRuleData"] = CloudWorkloadSecurityAgentRuleData
-
-
 class CloudWorkloadSecurityAgentRulesListResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.cloud_workload_security_agent_rule_data import (
+            CloudWorkloadSecurityAgentRuleData,
+        )
+
         return {
             "data": ([CloudWorkloadSecurityAgentRuleData],),
         }
