@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class IncidentNotificationHandle(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "display_name": (str,),
             "handle": (str,),
@@ -25,8 +22,6 @@ class IncidentNotificationHandle(ModelNormal):
         "handle": "handle",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         A notification handle that will be notified at incident creation.
