@@ -9,12 +9,6 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.user import User
-
-    globals()["User"] = User
-
-
 class IncidentResponseIncludedItem(ModelComposed):
     def __init__(self, *args, **kwargs):
         """
@@ -55,10 +49,9 @@ class IncidentResponseIncludedItem(ModelComposed):
         # code would be run when this module is imported, and these composed
         # classes don't exist yet because their module has not finished
         # loading
-        lazy_import()
+        from datadog_api_client.v2.model.user import User
+
         return {
-            "anyOf": [],
-            "allOf": [],
             "oneOf": [
                 User,
             ],
