@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.incident_response_meta_pagination import IncidentResponseMetaPagination
-
-    globals()["IncidentResponseMetaPagination"] = IncidentResponseMetaPagination
-
-
 class IncidentResponseMeta(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.incident_response_meta_pagination import IncidentResponseMetaPagination
+
         return {
             "pagination": (IncidentResponseMetaPagination,),
         }
