@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.incident_service_create_data import IncidentServiceCreateData
-
-    globals()["IncidentServiceCreateData"] = IncidentServiceCreateData
-
-
 class IncidentServiceCreateRequest(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.incident_service_create_data import IncidentServiceCreateData
+
         return {
             "data": (IncidentServiceCreateData,),
         }
