@@ -9,20 +9,13 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.incident_team_response_data import IncidentTeamResponseData
-    from datadog_api_client.v2.model.incident_team_included_items import IncidentTeamIncludedItems
-    from datadog_api_client.v2.model.incident_response_meta import IncidentResponseMeta
-
-    globals()["IncidentTeamResponseData"] = IncidentTeamResponseData
-    globals()["IncidentTeamIncludedItems"] = IncidentTeamIncludedItems
-    globals()["IncidentResponseMeta"] = IncidentResponseMeta
-
-
 class IncidentTeamsResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.incident_team_response_data import IncidentTeamResponseData
+        from datadog_api_client.v2.model.incident_team_included_items import IncidentTeamIncludedItems
+        from datadog_api_client.v2.model.incident_response_meta import IncidentResponseMeta
+
         return {
             "data": ([IncidentTeamResponseData],),
             "included": ([IncidentTeamIncludedItems],),
