@@ -9,22 +9,15 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.nullable_relationship_to_user import NullableRelationshipToUser
-    from datadog_api_client.v2.model.relationship_to_incident_integration_metadatas import (
-        RelationshipToIncidentIntegrationMetadatas,
-    )
-    from datadog_api_client.v2.model.relationship_to_incident_postmortem import RelationshipToIncidentPostmortem
-
-    globals()["NullableRelationshipToUser"] = NullableRelationshipToUser
-    globals()["RelationshipToIncidentIntegrationMetadatas"] = RelationshipToIncidentIntegrationMetadatas
-    globals()["RelationshipToIncidentPostmortem"] = RelationshipToIncidentPostmortem
-
-
 class IncidentUpdateRelationships(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.nullable_relationship_to_user import NullableRelationshipToUser
+        from datadog_api_client.v2.model.relationship_to_incident_integration_metadatas import (
+            RelationshipToIncidentIntegrationMetadatas,
+        )
+        from datadog_api_client.v2.model.relationship_to_incident_postmortem import RelationshipToIncidentPostmortem
+
         return {
             "commander_user": (NullableRelationshipToUser,),
             "integrations": (RelationshipToIncidentIntegrationMetadatas,),
