@@ -9,18 +9,12 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.logs_archive_order_attributes import LogsArchiveOrderAttributes
-    from datadog_api_client.v2.model.logs_archive_order_definition_type import LogsArchiveOrderDefinitionType
-
-    globals()["LogsArchiveOrderAttributes"] = LogsArchiveOrderAttributes
-    globals()["LogsArchiveOrderDefinitionType"] = LogsArchiveOrderDefinitionType
-
-
 class LogsArchiveOrderDefinition(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.logs_archive_order_attributes import LogsArchiveOrderAttributes
+        from datadog_api_client.v2.model.logs_archive_order_definition_type import LogsArchiveOrderDefinitionType
+
         return {
             "attributes": (LogsArchiveOrderAttributes,),
             "type": (LogsArchiveOrderDefinitionType,),
