@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class LogsMetricFilter(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "query": (str,),
         }
@@ -23,8 +20,6 @@ class LogsMetricFilter(ModelNormal):
         "query": "query",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         The log-based metric filter. Logs matching this filter will be aggregated in this metric.
