@@ -3,18 +3,15 @@
 # Copyright 2019-Present Datadog, Inc.
 
 
-from datadog_api_client.v2.model_utils import (
+from datadog_api_client.model_utils import (
     ModelNormal,
     cached_property,
 )
 
 
 class LogsQueryOptions(ModelNormal):
-
-    validations = {}
-
     @cached_property
-    def openapi_types():
+    def openapi_types(_):
         return {
             "time_offset": (int,),
             "timezone": (str,),
@@ -25,8 +22,6 @@ class LogsQueryOptions(ModelNormal):
         "timezone": "timezone",
     }
 
-    read_only_vars = {}
-
     def __init__(self, *args, **kwargs):
         """
         Global query options that are used during the query.
