@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.metric_all_tags import MetricAllTags
-
-    globals()["MetricAllTags"] = MetricAllTags
-
-
 class MetricAllTagsResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.metric_all_tags import MetricAllTags
+
         return {
             "data": (MetricAllTags,),
         }
