@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.metric_bulk_tag_config_email_list import MetricBulkTagConfigEmailList
-
-    globals()["MetricBulkTagConfigEmailList"] = MetricBulkTagConfigEmailList
-
-
 class MetricBulkTagConfigDeleteAttributes(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.metric_bulk_tag_config_email_list import MetricBulkTagConfigEmailList
+
         return {
             "emails": (MetricBulkTagConfigEmailList,),
         }
