@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.metric_bulk_tag_config_status import MetricBulkTagConfigStatus
-
-    globals()["MetricBulkTagConfigStatus"] = MetricBulkTagConfigStatus
-
-
 class MetricBulkTagConfigResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.metric_bulk_tag_config_status import MetricBulkTagConfigStatus
+
         return {
             "data": (MetricBulkTagConfigStatus,),
         }
