@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.metric_tag_configuration import MetricTagConfiguration
-
-    globals()["MetricTagConfiguration"] = MetricTagConfiguration
-
-
 class MetricTagConfigurationResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.metric_tag_configuration import MetricTagConfiguration
+
         return {
             "data": (MetricTagConfiguration,),
         }
