@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.relationship_to_organization_data import RelationshipToOrganizationData
-
-    globals()["RelationshipToOrganizationData"] = RelationshipToOrganizationData
-
-
 class RelationshipToOrganization(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.relationship_to_organization_data import RelationshipToOrganizationData
+
         return {
             "data": (RelationshipToOrganizationData,),
         }
