@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.organizations_type import OrganizationsType
-
-    globals()["OrganizationsType"] = OrganizationsType
-
-
 class RelationshipToOrganizationData(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.organizations_type import OrganizationsType
+
         return {
             "id": (str,),
             "type": (OrganizationsType,),
