@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.relationship_to_role_data import RelationshipToRoleData
-
-    globals()["RelationshipToRoleData"] = RelationshipToRoleData
-
-
 class RelationshipToRoles(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.relationship_to_role_data import RelationshipToRoleData
+
         return {
             "data": ([RelationshipToRoleData],),
         }
