@@ -9,18 +9,13 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.relationship_to_saml_assertion_attribute_data import (
-        RelationshipToSAMLAssertionAttributeData,
-    )
-
-    globals()["RelationshipToSAMLAssertionAttributeData"] = RelationshipToSAMLAssertionAttributeData
-
-
 class RelationshipToSAMLAssertionAttribute(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.relationship_to_saml_assertion_attribute_data import (
+            RelationshipToSAMLAssertionAttributeData,
+        )
+
         return {
             "data": (RelationshipToSAMLAssertionAttributeData,),
         }
