@@ -9,18 +9,12 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.role_clone_attributes import RoleCloneAttributes
-    from datadog_api_client.v2.model.roles_type import RolesType
-
-    globals()["RoleCloneAttributes"] = RoleCloneAttributes
-    globals()["RolesType"] = RolesType
-
-
 class RoleClone(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.role_clone_attributes import RoleCloneAttributes
+        from datadog_api_client.v2.model.roles_type import RolesType
+
         return {
             "attributes": (RoleCloneAttributes,),
             "type": (RolesType,),
