@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.role_update_response_data import RoleUpdateResponseData
-
-    globals()["RoleUpdateResponseData"] = RoleUpdateResponseData
-
-
 class RoleUpdateResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.role_update_response_data import RoleUpdateResponseData
+
         return {
             "data": (RoleUpdateResponseData,),
         }
