@@ -9,18 +9,12 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.security_filter_attributes import SecurityFilterAttributes
-    from datadog_api_client.v2.model.security_filter_type import SecurityFilterType
-
-    globals()["SecurityFilterAttributes"] = SecurityFilterAttributes
-    globals()["SecurityFilterType"] = SecurityFilterType
-
-
 class SecurityFilter(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.security_filter_attributes import SecurityFilterAttributes
+        from datadog_api_client.v2.model.security_filter_type import SecurityFilterType
+
         return {
             "attributes": (SecurityFilterAttributes,),
             "id": (str,),
@@ -43,7 +37,7 @@ class SecurityFilter(ModelNormal):
         :param id: The ID of the security filter.
         :type id: str, optional
 
-        :param type: The type of the resource. The value should always be `security_filters`.
+        :param type: The type of the resource. The value should always be ``security_filters``.
         :type type: SecurityFilterType, optional
         """
         super().__init__(kwargs)
