@@ -9,18 +9,12 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.security_filter_exclusion_filter import SecurityFilterExclusionFilter
-    from datadog_api_client.v2.model.security_filter_filtered_data_type import SecurityFilterFilteredDataType
-
-    globals()["SecurityFilterExclusionFilter"] = SecurityFilterExclusionFilter
-    globals()["SecurityFilterFilteredDataType"] = SecurityFilterFilteredDataType
-
-
 class SecurityFilterCreateAttributes(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.security_filter_exclusion_filter import SecurityFilterExclusionFilter
+        from datadog_api_client.v2.model.security_filter_filtered_data_type import SecurityFilterFilteredDataType
+
         return {
             "exclusion_filters": ([SecurityFilterExclusionFilter],),
             "filtered_data_type": (SecurityFilterFilteredDataType,),
