@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.security_filter_create_data import SecurityFilterCreateData
-
-    globals()["SecurityFilterCreateData"] = SecurityFilterCreateData
-
-
 class SecurityFilterCreateRequest(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.security_filter_create_data import SecurityFilterCreateData
+
         return {
             "data": (SecurityFilterCreateData,),
         }
