@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.security_filter_update_data import SecurityFilterUpdateData
-
-    globals()["SecurityFilterUpdateData"] = SecurityFilterUpdateData
-
-
 class SecurityFilterUpdateRequest(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.security_filter_update_data import SecurityFilterUpdateData
+
         return {
             "data": (SecurityFilterUpdateData,),
         }
