@@ -9,24 +9,15 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.security_monitoring_rule_case import SecurityMonitoringRuleCase
-    from datadog_api_client.v2.model.security_monitoring_filter import SecurityMonitoringFilter
-    from datadog_api_client.v2.model.security_monitoring_rule_options import SecurityMonitoringRuleOptions
-    from datadog_api_client.v2.model.security_monitoring_rule_query import SecurityMonitoringRuleQuery
-    from datadog_api_client.v2.model.security_monitoring_rule_type_read import SecurityMonitoringRuleTypeRead
-
-    globals()["SecurityMonitoringRuleCase"] = SecurityMonitoringRuleCase
-    globals()["SecurityMonitoringFilter"] = SecurityMonitoringFilter
-    globals()["SecurityMonitoringRuleOptions"] = SecurityMonitoringRuleOptions
-    globals()["SecurityMonitoringRuleQuery"] = SecurityMonitoringRuleQuery
-    globals()["SecurityMonitoringRuleTypeRead"] = SecurityMonitoringRuleTypeRead
-
-
 class SecurityMonitoringRuleResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.security_monitoring_rule_case import SecurityMonitoringRuleCase
+        from datadog_api_client.v2.model.security_monitoring_filter import SecurityMonitoringFilter
+        from datadog_api_client.v2.model.security_monitoring_rule_options import SecurityMonitoringRuleOptions
+        from datadog_api_client.v2.model.security_monitoring_rule_query import SecurityMonitoringRuleQuery
+        from datadog_api_client.v2.model.security_monitoring_rule_type_read import SecurityMonitoringRuleTypeRead
+
         return {
             "cases": ([SecurityMonitoringRuleCase],),
             "created_at": (int,),
