@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.usage_data_object import UsageDataObject
-
-    globals()["UsageDataObject"] = UsageDataObject
-
-
 class UsageObservabilityPipelinesResponse(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.usage_data_object import UsageDataObject
+
         return {
             "data": ([UsageDataObject],),
         }
