@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.user_create_data import UserCreateData
-
-    globals()["UserCreateData"] = UserCreateData
-
-
 class UserCreateRequest(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.user_create_data import UserCreateData
+
         return {
             "data": (UserCreateData,),
         }
