@@ -9,16 +9,11 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.user_invitation_data import UserInvitationData
-
-    globals()["UserInvitationData"] = UserInvitationData
-
-
 class UserInvitationsRequest(ModelNormal):
     @cached_property
     def openapi_types(_):
-        lazy_import()
+        from datadog_api_client.v2.model.user_invitation_data import UserInvitationData
+
         return {
             "data": ([UserInvitationData],),
         }
