@@ -9,16 +9,6 @@ from datadog_api_client.model_utils import (
 )
 
 
-def lazy_import():
-    from datadog_api_client.v2.model.organization import Organization
-    from datadog_api_client.v2.model.permission import Permission
-    from datadog_api_client.v2.model.role import Role
-
-    globals()["Organization"] = Organization
-    globals()["Permission"] = Permission
-    globals()["Role"] = Role
-
-
 class UserResponseIncludedItem(ModelComposed):
     def __init__(self, *args, **kwargs):
         """
@@ -59,10 +49,11 @@ class UserResponseIncludedItem(ModelComposed):
         # code would be run when this module is imported, and these composed
         # classes don't exist yet because their module has not finished
         # loading
-        lazy_import()
+        from datadog_api_client.v2.model.organization import Organization
+        from datadog_api_client.v2.model.permission import Permission
+        from datadog_api_client.v2.model.role import Role
+
         return {
-            "anyOf": [],
-            "allOf": [],
             "oneOf": [
                 Organization,
                 Permission,
